## Cops

In RuboCop lingo the various checks performed on the code are called cops. There are several cop departments.

You can also load [custom cops](extensions.md#custom-cops).

### Style

Most of the cops in RuboCop are so called style cops that check for
stylistic problems in your code. Almost all of the them are based on
the Ruby Style Guide. Many of the style cops have configurations
options allowing them to support different popular coding
conventions.

### Lint

Lint cops check for possible errors and very bad practices in your
code. RuboCop implements in a portable way all built-in MRI lint
checks (`ruby -wc`) and adds a lot of extra lint checks of its
own. You can run only the lint cops like this:

```sh
$ rubocop -l
```

The `-l`/`--lint` option can be used together with `--only` to run all the
enabled lint cops plus a selection of other cops.

Disabling any of the lint cops is generally a bad idea.

### Metrics

Metrics cops deal with properties of the source code that can be measured,
such as class length, method length, etc. Generally speaking, they have a
configuration parameter called `Max` and when running
`rubocop --auto-gen-config`, this parameter will be set to the highest value
found for the inspected code.

### Performance

Performance cops catch Ruby idioms which are known to be slower than another
equivalent (and equally readable) idiom.

### Rails

Rails cops are specific to the Ruby on Rails framework. Unlike all
other cop types they are not used by default and you have to request
them specifically:

```sh
$ rubocop -R
```

or add the following directive to your `.rubocop.yml`:

```yaml
Rails:
  Enabled: true
```

### Bundler

Bundler cops check for style or bad practices in Bundler files, e.g. `Gemfile`.

### Available cops

In the following section you find all available cops:

<!-- START_COP_LIST -->
#### Department [Bundler](cops_bundler.md)

* [Bundler/DuplicatedGem](cops_bundler.md#bundlerduplicatedgem)
* [Bundler/OrderedGems](cops_bundler.md#bundlerorderedgems)

#### Department [Lint](cops_lint.md)

* [Lint/AmbiguousBlockAssociation](cops_lint.md#lintambiguousblockassociation)
* [Lint/AmbiguousOperator](cops_lint.md#lintambiguousoperator)
* [Lint/AmbiguousRegexpLiteral](cops_lint.md#lintambiguousregexpliteral)
* [Lint/AssignmentInCondition](cops_lint.md#lintassignmentincondition)
* [Lint/BlockAlignment](cops_lint.md#lintblockalignment)
* [Lint/CircularArgumentReference](cops_lint.md#lintcircularargumentreference)
* [Lint/ConditionPosition](cops_lint.md#lintconditionposition)
* [Lint/Debugger](cops_lint.md#lintdebugger)
* [Lint/DefEndAlignment](cops_lint.md#lintdefendalignment)
* [Lint/DeprecatedClassMethods](cops_lint.md#lintdeprecatedclassmethods)
* [Lint/DuplicateCaseCondition](cops_lint.md#lintduplicatecasecondition)
* [Lint/DuplicateMethods](cops_lint.md#lintduplicatemethods)
* [Lint/DuplicatedKey](cops_lint.md#lintduplicatedkey)
* [Lint/EachWithObjectArgument](cops_lint.md#linteachwithobjectargument)
* [Lint/ElseLayout](cops_lint.md#lintelselayout)
* [Lint/EmptyEnsure](cops_lint.md#lintemptyensure)
* [Lint/EmptyExpression](cops_lint.md#lintemptyexpression)
* [Lint/EmptyInterpolation](cops_lint.md#lintemptyinterpolation)
* [Lint/EmptyWhen](cops_lint.md#lintemptywhen)
* [Lint/EndAlignment](cops_lint.md#lintendalignment)
* [Lint/EndInMethod](cops_lint.md#lintendinmethod)
* [Lint/EnsureReturn](cops_lint.md#lintensurereturn)
* [Lint/FloatOutOfRange](cops_lint.md#lintfloatoutofrange)
* [Lint/FormatParameterMismatch](cops_lint.md#lintformatparametermismatch)
* [Lint/HandleExceptions](cops_lint.md#linthandleexceptions)
* [Lint/ImplicitStringConcatenation](cops_lint.md#lintimplicitstringconcatenation)
* [Lint/IneffectiveAccessModifier](cops_lint.md#lintineffectiveaccessmodifier)
* [Lint/InheritException](cops_lint.md#lintinheritexception)
* [Lint/InvalidCharacterLiteral](cops_lint.md#lintinvalidcharacterliteral)
* [Lint/LiteralInCondition](cops_lint.md#lintliteralincondition)
* [Lint/LiteralInInterpolation](cops_lint.md#lintliteralininterpolation)
* [Lint/Loop](cops_lint.md#lintloop)
* [Lint/MultipleCompare](cops_lint.md#lintmultiplecompare)
* [Lint/NestedMethodDefinition](cops_lint.md#lintnestedmethoddefinition)
* [Lint/NextWithoutAccumulator](cops_lint.md#lintnextwithoutaccumulator)
* [Lint/NonLocalExitFromIterator](cops_lint.md#lintnonlocalexitfromiterator)
* [Lint/ParenthesesAsGroupedExpression](cops_lint.md#lintparenthesesasgroupedexpression)
* [Lint/PercentStringArray](cops_lint.md#lintpercentstringarray)
* [Lint/PercentSymbolArray](cops_lint.md#lintpercentsymbolarray)
* [Lint/RandOne](cops_lint.md#lintrandone)
* [Lint/RequireParentheses](cops_lint.md#lintrequireparentheses)
* [Lint/RescueException](cops_lint.md#lintrescueexception)
* [Lint/SafeNavigationChain](cops_lint.md#lintsafenavigationchain)
* [Lint/ShadowedException](cops_lint.md#lintshadowedexception)
* [Lint/ShadowingOuterLocalVariable](cops_lint.md#lintshadowingouterlocalvariable)
* [Lint/StringConversionInInterpolation](cops_lint.md#lintstringconversionininterpolation)
* [Lint/UnderscorePrefixedVariableName](cops_lint.md#lintunderscoreprefixedvariablename)
* [Lint/UnifiedInteger](cops_lint.md#lintunifiedinteger)
* [Lint/UnneededDisable](cops_lint.md#lintunneededdisable)
* [Lint/UnneededSplatExpansion](cops_lint.md#lintunneededsplatexpansion)
* [Lint/UnreachableCode](cops_lint.md#lintunreachablecode)
* [Lint/UnusedBlockArgument](cops_lint.md#lintunusedblockargument)
* [Lint/UnusedMethodArgument](cops_lint.md#lintunusedmethodargument)
* [Lint/UselessAccessModifier](cops_lint.md#lintuselessaccessmodifier)
* [Lint/UselessAssignment](cops_lint.md#lintuselessassignment)
* [Lint/UselessComparison](cops_lint.md#lintuselesscomparison)
* [Lint/UselessElseWithoutRescue](cops_lint.md#lintuselesselsewithoutrescue)
* [Lint/UselessSetterCall](cops_lint.md#lintuselesssettercall)
* [Lint/Void](cops_lint.md#lintvoid)

#### Department [Metrics](cops_metrics.md)

* [Metrics/AbcSize](cops_metrics.md#metricsabcsize)
* [Metrics/BlockLength](cops_metrics.md#metricsblocklength)
* [Metrics/BlockNesting](cops_metrics.md#metricsblocknesting)
* [Metrics/ClassLength](cops_metrics.md#metricsclasslength)
* [Metrics/CyclomaticComplexity](cops_metrics.md#metricscyclomaticcomplexity)
* [Metrics/LineLength](cops_metrics.md#metricslinelength)
* [Metrics/MethodLength](cops_metrics.md#metricsmethodlength)
* [Metrics/ModuleLength](cops_metrics.md#metricsmodulelength)
* [Metrics/ParameterLists](cops_metrics.md#metricsparameterlists)
* [Metrics/PerceivedComplexity](cops_metrics.md#metricsperceivedcomplexity)

#### Department [Performance](cops_performance.md)

* [Performance/CaseWhenSplat](cops_performance.md#performancecasewhensplat)
* [Performance/Casecmp](cops_performance.md#performancecasecmp)
* [Performance/CompareWithBlock](cops_performance.md#performancecomparewithblock)
* [Performance/Count](cops_performance.md#performancecount)
* [Performance/Detect](cops_performance.md#performancedetect)
* [Performance/DoubleStartEndWith](cops_performance.md#performancedoublestartendwith)
* [Performance/EndWith](cops_performance.md#performanceendwith)
* [Performance/FixedSize](cops_performance.md#performancefixedsize)
* [Performance/FlatMap](cops_performance.md#performanceflatmap)
* [Performance/HashEachMethods](cops_performance.md#performancehasheachmethods)
* [Performance/LstripRstrip](cops_performance.md#performancelstriprstrip)
* [Performance/RangeInclude](cops_performance.md#performancerangeinclude)
* [Performance/RedundantBlockCall](cops_performance.md#performanceredundantblockcall)
* [Performance/RedundantMatch](cops_performance.md#performanceredundantmatch)
* [Performance/RedundantMerge](cops_performance.md#performanceredundantmerge)
* [Performance/RedundantSortBy](cops_performance.md#performanceredundantsortby)
* [Performance/RegexpMatch](cops_performance.md#performanceregexpmatch)
* [Performance/ReverseEach](cops_performance.md#performancereverseeach)
* [Performance/Sample](cops_performance.md#performancesample)
* [Performance/Size](cops_performance.md#performancesize)
* [Performance/StartWith](cops_performance.md#performancestartwith)
* [Performance/StringReplacement](cops_performance.md#performancestringreplacement)
* [Performance/TimesMap](cops_performance.md#performancetimesmap)

#### Department [Rails](cops_rails.md)

* [Rails/ActionFilter](cops_rails.md#railsactionfilter)
* [Rails/ActiveSupportAliases](cops_rails.md#railsactivesupportaliases)
* [Rails/Blank](cops_rails.md#railsblank)
* [Rails/Date](cops_rails.md#railsdate)
* [Rails/Delegate](cops_rails.md#railsdelegate)
* [Rails/DelegateAllowBlank](cops_rails.md#railsdelegateallowblank)
* [Rails/DynamicFindBy](cops_rails.md#railsdynamicfindby)
* [Rails/EnumUniqueness](cops_rails.md#railsenumuniqueness)
* [Rails/Exit](cops_rails.md#railsexit)
* [Rails/FilePath](cops_rails.md#railsfilepath)
* [Rails/FindBy](cops_rails.md#railsfindby)
* [Rails/FindEach](cops_rails.md#railsfindeach)
* [Rails/HasAndBelongsToMany](cops_rails.md#railshasandbelongstomany)
* [Rails/HttpPositionalArguments](cops_rails.md#railshttppositionalarguments)
* [Rails/NotNullColumn](cops_rails.md#railsnotnullcolumn)
* [Rails/Output](cops_rails.md#railsoutput)
* [Rails/OutputSafety](cops_rails.md#railsoutputsafety)
* [Rails/PluralizationGrammar](cops_rails.md#railspluralizationgrammar)
* [Rails/Present](cops_rails.md#railspresent)
* [Rails/ReadWriteAttribute](cops_rails.md#railsreadwriteattribute)
* [Rails/RelativeDateConstant](cops_rails.md#railsrelativedateconstant)
* [Rails/RequestReferer](cops_rails.md#railsrequestreferer)
* [Rails/ReversibleMigration](cops_rails.md#railsreversiblemigration)
* [Rails/SafeNavigation](cops_rails.md#railssafenavigation)
* [Rails/SaveBang](cops_rails.md#railssavebang)
* [Rails/ScopeArgs](cops_rails.md#railsscopeargs)
* [Rails/SkipsModelValidations](cops_rails.md#railsskipsmodelvalidations)
* [Rails/TimeZone](cops_rails.md#railstimezone)
* [Rails/UniqBeforePluck](cops_rails.md#railsuniqbeforepluck)
* [Rails/Validation](cops_rails.md#railsvalidation)

#### Department [Security](cops_security.md)

* [Security/Eval](cops_security.md#securityeval)
* [Security/JSONLoad](cops_security.md#securityjsonload)
* [Security/MarshalLoad](cops_security.md#securitymarshalload)
* [Security/YAMLLoad](cops_security.md#securityyamlload)

#### Department [Style](cops_style.md)

* [Style/AccessModifierIndentation](cops_style.md#styleaccessmodifierindentation)
* [Style/AccessorMethodName](cops_style.md#styleaccessormethodname)
* [Style/Alias](cops_style.md#stylealias)
* [Style/AlignArray](cops_style.md#stylealignarray)
* [Style/AlignHash](cops_style.md#stylealignhash)
* [Style/AlignParameters](cops_style.md#stylealignparameters)
* [Style/AndOr](cops_style.md#styleandor)
* [Style/ArrayJoin](cops_style.md#stylearrayjoin)
* [Style/AsciiComments](cops_style.md#styleasciicomments)
* [Style/AsciiIdentifiers](cops_style.md#styleasciiidentifiers)
* [Style/Attr](cops_style.md#styleattr)
* [Style/AutoResourceCleanup](cops_style.md#styleautoresourcecleanup)
* [Style/BarePercentLiterals](cops_style.md#stylebarepercentliterals)
* [Style/BeginBlock](cops_style.md#stylebeginblock)
* [Style/BlockComments](cops_style.md#styleblockcomments)
* [Style/BlockDelimiters](cops_style.md#styleblockdelimiters)
* [Style/BlockEndNewline](cops_style.md#styleblockendnewline)
* [Style/BracesAroundHashParameters](cops_style.md#stylebracesaroundhashparameters)
* [Style/CaseEquality](cops_style.md#stylecaseequality)
* [Style/CaseIndentation](cops_style.md#stylecaseindentation)
* [Style/CharacterLiteral](cops_style.md#stylecharacterliteral)
* [Style/ClassAndModuleCamelCase](cops_style.md#styleclassandmodulecamelcase)
* [Style/ClassAndModuleChildren](cops_style.md#styleclassandmodulechildren)
* [Style/ClassCheck](cops_style.md#styleclasscheck)
* [Style/ClassMethods](cops_style.md#styleclassmethods)
* [Style/ClassVars](cops_style.md#styleclassvars)
* [Style/ClosingParenthesisIndentation](cops_style.md#styleclosingparenthesisindentation)
* [Style/CollectionMethods](cops_style.md#stylecollectionmethods)
* [Style/ColonMethodCall](cops_style.md#stylecolonmethodcall)
* [Style/CommandLiteral](cops_style.md#stylecommandliteral)
* [Style/CommentAnnotation](cops_style.md#stylecommentannotation)
* [Style/CommentIndentation](cops_style.md#stylecommentindentation)
* [Style/ConditionalAssignment](cops_style.md#styleconditionalassignment)
* [Style/ConstantName](cops_style.md#styleconstantname)
* [Style/Copyright](cops_style.md#stylecopyright)
* [Style/DefWithParentheses](cops_style.md#styledefwithparentheses)
* [Style/Documentation](cops_style.md#styledocumentation)
* [Style/DocumentationMethod](cops_style.md#styledocumentationmethod)
* [Style/DotPosition](cops_style.md#styledotposition)
* [Style/DoubleNegation](cops_style.md#styledoublenegation)
* [Style/EachForSimpleLoop](cops_style.md#styleeachforsimpleloop)
* [Style/EachWithObject](cops_style.md#styleeachwithobject)
* [Style/ElseAlignment](cops_style.md#styleelsealignment)
* [Style/EmptyCaseCondition](cops_style.md#styleemptycasecondition)
* [Style/EmptyElse](cops_style.md#styleemptyelse)
* [Style/EmptyLineAfterMagicComment](cops_style.md#styleemptylineaftermagiccomment)
* [Style/EmptyLineBetweenDefs](cops_style.md#styleemptylinebetweendefs)
* [Style/EmptyLines](cops_style.md#styleemptylines)
* [Style/EmptyLinesAroundAccessModifier](cops_style.md#styleemptylinesaroundaccessmodifier)
* [Style/EmptyLinesAroundBeginBody](cops_style.md#styleemptylinesaroundbeginbody)
* [Style/EmptyLinesAroundBlockBody](cops_style.md#styleemptylinesaroundblockbody)
* [Style/EmptyLinesAroundClassBody](cops_style.md#styleemptylinesaroundclassbody)
* [Style/EmptyLinesAroundExceptionHandlingKeywords](cops_style.md#styleemptylinesaroundexceptionhandlingkeywords)
* [Style/EmptyLinesAroundMethodBody](cops_style.md#styleemptylinesaroundmethodbody)
* [Style/EmptyLinesAroundModuleBody](cops_style.md#styleemptylinesaroundmodulebody)
* [Style/EmptyLiteral](cops_style.md#styleemptyliteral)
* [Style/EmptyMethod](cops_style.md#styleemptymethod)
* [Style/Encoding](cops_style.md#styleencoding)
* [Style/EndBlock](cops_style.md#styleendblock)
* [Style/EndOfLine](cops_style.md#styleendofline)
* [Style/EvenOdd](cops_style.md#styleevenodd)
* [Style/ExtraSpacing](cops_style.md#styleextraspacing)
* [Style/FileName](cops_style.md#stylefilename)
* [Style/FirstArrayElementLineBreak](cops_style.md#stylefirstarrayelementlinebreak)
* [Style/FirstHashElementLineBreak](cops_style.md#stylefirsthashelementlinebreak)
* [Style/FirstMethodArgumentLineBreak](cops_style.md#stylefirstmethodargumentlinebreak)
* [Style/FirstMethodParameterLineBreak](cops_style.md#stylefirstmethodparameterlinebreak)
* [Style/FirstParameterIndentation](cops_style.md#stylefirstparameterindentation)
* [Style/FlipFlop](cops_style.md#styleflipflop)
* [Style/For](cops_style.md#stylefor)
* [Style/FormatString](cops_style.md#styleformatstring)
* [Style/FrozenStringLiteralComment](cops_style.md#stylefrozenstringliteralcomment)
* [Style/GlobalVars](cops_style.md#styleglobalvars)
* [Style/GuardClause](cops_style.md#styleguardclause)
* [Style/HashSyntax](cops_style.md#stylehashsyntax)
* [Style/IdenticalConditionalBranches](cops_style.md#styleidenticalconditionalbranches)
* [Style/IfInsideElse](cops_style.md#styleifinsideelse)
* [Style/IfUnlessModifier](cops_style.md#styleifunlessmodifier)
* [Style/IfUnlessModifierOfIfUnless](cops_style.md#styleifunlessmodifierofifunless)
* [Style/IfWithSemicolon](cops_style.md#styleifwithsemicolon)
* [Style/ImplicitRuntimeError](cops_style.md#styleimplicitruntimeerror)
* [Style/IndentArray](cops_style.md#styleindentarray)
* [Style/IndentAssignment](cops_style.md#styleindentassignment)
* [Style/IndentHash](cops_style.md#styleindenthash)
* [Style/IndentHeredoc](cops_style.md#styleindentheredoc)
* [Style/IndentationConsistency](cops_style.md#styleindentationconsistency)
* [Style/IndentationWidth](cops_style.md#styleindentationwidth)
* [Style/InfiniteLoop](cops_style.md#styleinfiniteloop)
* [Style/InitialIndentation](cops_style.md#styleinitialindentation)
* [Style/InlineComment](cops_style.md#styleinlinecomment)
* [Style/InverseMethods](cops_style.md#styleinversemethods)
* [Style/Lambda](cops_style.md#stylelambda)
* [Style/LambdaCall](cops_style.md#stylelambdacall)
* [Style/LeadingCommentSpace](cops_style.md#styleleadingcommentspace)
* [Style/LineEndConcatenation](cops_style.md#stylelineendconcatenation)
* [Style/MethodCallWithArgsParentheses](cops_style.md#stylemethodcallwithargsparentheses)
* [Style/MethodCallWithoutArgsParentheses](cops_style.md#stylemethodcallwithoutargsparentheses)
* [Style/MethodCalledOnDoEndBlock](cops_style.md#stylemethodcalledondoendblock)
* [Style/MethodDefParentheses](cops_style.md#stylemethoddefparentheses)
* [Style/MethodMissing](cops_style.md#stylemethodmissing)
* [Style/MethodName](cops_style.md#stylemethodname)
* [Style/MissingElse](cops_style.md#stylemissingelse)
* [Style/MixinGrouping](cops_style.md#stylemixingrouping)
* [Style/ModuleFunction](cops_style.md#stylemodulefunction)
* [Style/MultilineArrayBraceLayout](cops_style.md#stylemultilinearraybracelayout)
* [Style/MultilineAssignmentLayout](cops_style.md#stylemultilineassignmentlayout)
* [Style/MultilineBlockChain](cops_style.md#stylemultilineblockchain)
* [Style/MultilineBlockLayout](cops_style.md#stylemultilineblocklayout)
* [Style/MultilineHashBraceLayout](cops_style.md#stylemultilinehashbracelayout)
* [Style/MultilineIfModifier](cops_style.md#stylemultilineifmodifier)
* [Style/MultilineIfThen](cops_style.md#stylemultilineifthen)
* [Style/MultilineMemoization](cops_style.md#stylemultilinememoization)
* [Style/MultilineMethodCallBraceLayout](cops_style.md#stylemultilinemethodcallbracelayout)
* [Style/MultilineMethodCallIndentation](cops_style.md#stylemultilinemethodcallindentation)
* [Style/MultilineMethodDefinitionBraceLayout](cops_style.md#stylemultilinemethoddefinitionbracelayout)
* [Style/MultilineOperationIndentation](cops_style.md#stylemultilineoperationindentation)
* [Style/MultilineTernaryOperator](cops_style.md#stylemultilineternaryoperator)
* [Style/MutableConstant](cops_style.md#stylemutableconstant)
* [Style/NegatedIf](cops_style.md#stylenegatedif)
* [Style/NegatedWhile](cops_style.md#stylenegatedwhile)
* [Style/NestedModifier](cops_style.md#stylenestedmodifier)
* [Style/NestedParenthesizedCalls](cops_style.md#stylenestedparenthesizedcalls)
* [Style/NestedTernaryOperator](cops_style.md#stylenestedternaryoperator)
* [Style/Next](cops_style.md#stylenext)
* [Style/NilComparison](cops_style.md#stylenilcomparison)
* [Style/NonNilCheck](cops_style.md#stylenonnilcheck)
* [Style/Not](cops_style.md#stylenot)
* [Style/NumericLiteralPrefix](cops_style.md#stylenumericliteralprefix)
* [Style/NumericLiterals](cops_style.md#stylenumericliterals)
* [Style/NumericPredicate](cops_style.md#stylenumericpredicate)
* [Style/OneLineConditional](cops_style.md#styleonelineconditional)
* [Style/OpMethod](cops_style.md#styleopmethod)
* [Style/OptionHash](cops_style.md#styleoptionhash)
* [Style/OptionalArguments](cops_style.md#styleoptionalarguments)
* [Style/ParallelAssignment](cops_style.md#styleparallelassignment)
* [Style/ParenthesesAroundCondition](cops_style.md#styleparenthesesaroundcondition)
* [Style/PercentLiteralDelimiters](cops_style.md#stylepercentliteraldelimiters)
* [Style/PercentQLiterals](cops_style.md#stylepercentqliterals)
* [Style/PerlBackrefs](cops_style.md#styleperlbackrefs)
* [Style/PredicateName](cops_style.md#stylepredicatename)
* [Style/PreferredHashMethods](cops_style.md#stylepreferredhashmethods)
* [Style/Proc](cops_style.md#styleproc)
* [Style/RaiseArgs](cops_style.md#styleraiseargs)
* [Style/RedundantBegin](cops_style.md#styleredundantbegin)
* [Style/RedundantException](cops_style.md#styleredundantexception)
* [Style/RedundantFreeze](cops_style.md#styleredundantfreeze)
* [Style/RedundantParentheses](cops_style.md#styleredundantparentheses)
* [Style/RedundantReturn](cops_style.md#styleredundantreturn)
* [Style/RedundantSelf](cops_style.md#styleredundantself)
* [Style/RegexpLiteral](cops_style.md#styleregexpliteral)
* [Style/RescueEnsureAlignment](cops_style.md#stylerescueensurealignment)
* [Style/RescueModifier](cops_style.md#stylerescuemodifier)
* [Style/SafeNavigation](cops_style.md#stylesafenavigation)
* [Style/SelfAssignment](cops_style.md#styleselfassignment)
* [Style/Semicolon](cops_style.md#stylesemicolon)
* [Style/Send](cops_style.md#stylesend)
* [Style/SignalException](cops_style.md#stylesignalexception)
* [Style/SingleLineBlockParams](cops_style.md#stylesinglelineblockparams)
* [Style/SingleLineMethods](cops_style.md#stylesinglelinemethods)
* [Style/SpaceAfterColon](cops_style.md#stylespaceaftercolon)
* [Style/SpaceAfterComma](cops_style.md#stylespaceaftercomma)
* [Style/SpaceAfterMethodName](cops_style.md#stylespaceaftermethodname)
* [Style/SpaceAfterNot](cops_style.md#stylespaceafternot)
* [Style/SpaceAfterSemicolon](cops_style.md#stylespaceaftersemicolon)
* [Style/SpaceAroundBlockParameters](cops_style.md#stylespacearoundblockparameters)
* [Style/SpaceAroundEqualsInParameterDefault](cops_style.md#stylespacearoundequalsinparameterdefault)
* [Style/SpaceAroundKeyword](cops_style.md#stylespacearoundkeyword)
* [Style/SpaceAroundOperators](cops_style.md#stylespacearoundoperators)
* [Style/SpaceBeforeBlockBraces](cops_style.md#stylespacebeforeblockbraces)
* [Style/SpaceBeforeComma](cops_style.md#stylespacebeforecomma)
* [Style/SpaceBeforeComment](cops_style.md#stylespacebeforecomment)
* [Style/SpaceBeforeFirstArg](cops_style.md#stylespacebeforefirstarg)
* [Style/SpaceBeforeSemicolon](cops_style.md#stylespacebeforesemicolon)
* [Style/SpaceInLambdaLiteral](cops_style.md#stylespaceinlambdaliteral)
* [Style/SpaceInsideArrayPercentLiteral](cops_style.md#stylespaceinsidearraypercentliteral)
* [Style/SpaceInsideBlockBraces](cops_style.md#stylespaceinsideblockbraces)
* [Style/SpaceInsideBrackets](cops_style.md#stylespaceinsidebrackets)
* [Style/SpaceInsideHashLiteralBraces](cops_style.md#stylespaceinsidehashliteralbraces)
* [Style/SpaceInsideParens](cops_style.md#stylespaceinsideparens)
* [Style/SpaceInsidePercentLiteralDelimiters](cops_style.md#stylespaceinsidepercentliteraldelimiters)
* [Style/SpaceInsideRangeLiteral](cops_style.md#stylespaceinsiderangeliteral)
* [Style/SpaceInsideStringInterpolation](cops_style.md#stylespaceinsidestringinterpolation)
* [Style/SpecialGlobalVars](cops_style.md#stylespecialglobalvars)
* [Style/StabbyLambdaParentheses](cops_style.md#stylestabbylambdaparentheses)
* [Style/StringLiterals](cops_style.md#stylestringliterals)
* [Style/StringLiteralsInInterpolation](cops_style.md#stylestringliteralsininterpolation)
* [Style/StringMethods](cops_style.md#stylestringmethods)
* [Style/StructInheritance](cops_style.md#stylestructinheritance)
* [Style/SymbolArray](cops_style.md#stylesymbolarray)
* [Style/SymbolLiteral](cops_style.md#stylesymbolliteral)
* [Style/SymbolProc](cops_style.md#stylesymbolproc)
* [Style/Tab](cops_style.md#styletab)
* [Style/TernaryParentheses](cops_style.md#styleternaryparentheses)
* [Style/TrailingBlankLines](cops_style.md#styletrailingblanklines)
* [Style/TrailingCommaInArguments](cops_style.md#styletrailingcommainarguments)
* [Style/TrailingCommaInLiteral](cops_style.md#styletrailingcommainliteral)
* [Style/TrailingUnderscoreVariable](cops_style.md#styletrailingunderscorevariable)
* [Style/TrailingWhitespace](cops_style.md#styletrailingwhitespace)
* [Style/TrivialAccessors](cops_style.md#styletrivialaccessors)
* [Style/UnlessElse](cops_style.md#styleunlesselse)
* [Style/UnneededCapitalW](cops_style.md#styleunneededcapitalw)
* [Style/UnneededInterpolation](cops_style.md#styleunneededinterpolation)
* [Style/UnneededPercentQ](cops_style.md#styleunneededpercentq)
* [Style/VariableInterpolation](cops_style.md#stylevariableinterpolation)
* [Style/VariableName](cops_style.md#stylevariablename)
* [Style/VariableNumber](cops_style.md#stylevariablenumber)
* [Style/WhenThen](cops_style.md#stylewhenthen)
* [Style/WhileUntilDo](cops_style.md#stylewhileuntildo)
* [Style/WhileUntilModifier](cops_style.md#stylewhileuntilmodifier)
* [Style/WordArray](cops_style.md#stylewordarray)
* [Style/ZeroLengthPredicate](cops_style.md#stylezerolengthpredicate)

<!-- END_COP_LIST -->
